@@ -1,5 +1,5 @@
 # UMLS::Interface 
-# (Last Updated $Id: Interface.pm,v 1.147 2016/01/07 22:49:33 btmcinnes Exp $)
+# (Last Updated $Id: Interface.pm,v 1.150 2016/07/11 16:36:48 btmcinnes Exp $)
 #
 # Perl module that provides a perl interface to the
 # Unified Medical Language System (UMLS)
@@ -421,7 +421,7 @@ my $pkg = "UMLS::Interface";
 
 use vars qw($VERSION);
 
-$VERSION = '1.47';
+$VERSION = '1.49';
 
 my $debug = 0;
 
@@ -2431,6 +2431,41 @@ sub getSt {
     return $array;
 }
 
+ 
+=head3 getSt
+
+description:
+
+ returns the semantic type(s) of a given concept
+
+input:   
+
+output:
+
+ $array   <- reference to an array containing all the semantic type's TUIs
+             
+
+example:
+
+ use UMLS::Interface;
+ my $umls = UMLS::Interface->new(); 
+	
+ my $concept  = "C0018563";	
+ my $array    = $umls->getAllSts(); 
+ print "The semantic types in the UMLS are: \n"; 
+ foreach my $st (@{$array}) { print "  $st\n"; }
+
+=cut
+sub getAllSts {
+
+    my $self = shift;
+    my $concept   = shift;
+
+    my $array = $cuifinder->_getAllSts(); 
+    
+    return $array;
+}
+
 =head3 getSemanticGroup
 
 description:
@@ -2466,6 +2501,73 @@ sub getSemanticGroup {
     return $array;
 }
 
+=head3 getAllSemanticGroups
+
+description:
+
+ function returns all the semantic groups
+
+input:   
+
+output:
+
+ $array   <- $array reference containing semantic groups
+
+example:
+
+ use UMLS::Interface;
+ my $umls = UMLS::Interface->new(); 
+	
+ my $concept  = "C0018563";	
+ my $array    = $umls->getAllSemanticGroups(); 
+ print "The semantic groups are:\n";
+ foreach my $sg (@{$array}) { print "  $sg\n"; }
+
+=cut
+sub getAllSemanticGroups {
+
+    my $self = shift;
+    
+    my $array = $cuifinder->_getAllSemanticGroups(); 
+
+    return $array;
+}
+
+=head3 getStsFromSg
+
+description:
+
+ function returns all the semantic types of a given semantic group
+
+input:   
+
+ $string <- semantic group code
+
+output:
+
+ $array   <- $array reference containing semantic types
+
+example:
+
+ use UMLS::Interface;
+ my $umls = UMLS::Interface->new(); 
+	
+ my $sg  = "PROC";	
+ my $array    = $umls->getStsFromSg($sg); 
+ print "The semantic types are:\n";
+ foreach my $st (@{$array}) { print "  $st\n"; }
+
+=cut
+sub getStsFromSg { 
+
+    my $self = shift;
+    my $sg  = shift;
+    
+    my $array = $cuifinder->_getStsFromSg($sg); 
+
+    return $array;
+}
+
 =head3 stGetSemanticGroup
 
 description:
