@@ -1,5 +1,5 @@
 # UMLS::Interface::PathFinder
-# (Last Updated $Id: PathFinder.pm,v 1.66 2015/06/23 14:17:23 btmcinnes Exp $)
+# (Last Updated $Id: PathFinder.pm,v 1.67 2015/12/29 17:51:41 btmcinnes Exp $)
 #
 # Perl module that provides a perl interface to the
 # Unified Medical Language System (UMLS)
@@ -1612,10 +1612,10 @@ sub _joinPathsToCenter {
 	    #  if the two centers are equal we have path
 	    if($c1 eq $c2) { 
 		
-		#  if undirected makke certain that their is at 
+		#  if undirected make certain that their is at 
 		#  most one direction change
 		if(!($option_undirected)) { 
-		    
+
 		    #  check on basic direction changes
 		    my $totalchanges = $dchange1 + $dchange2;
 		    if($totalchanges > 1)               { next; } 
@@ -1624,14 +1624,16 @@ sub _joinPathsToCenter {
 		    #  set the path
 		    my @rarray2 = reverse @array2;
 		    my @path = (@array1, @rarray2);
-
+		    
 		    #  check for complicated embedded direction changes
-		    my $direction = 0; my $previous = "";
+		    my $direction = 0; my $previous = ""; my $cflag = 0; 
 		    for my $i (0..($#path-1)) { 
 			my $cc1 = $path[$i];
 			my $cc2 = $path[$i+1];
+
 			#  get the relationships the concepts
 			my $ccr = $cuifinder->_getRelationsBetweenCuis($cc1, $cc2);
+
 			#  determine whether that relation is a 
 			#  parent or a child relation
 			my $pr = 0; my $cr = 0;
@@ -1640,8 +1642,15 @@ sub _joinPathsToCenter {
 			    my $rel = $1; 
 			    if($childstring=~/($rel)/)  { $cr++; }
 			    if($parentstring=~/($rel)/) { $pr++; }
+
+
+			    #  determine that the first relationship in the 
+			    #  in the path is not a child relation 
+			    if($i == 0) { 
+				if($childstring=~/($rel)/) { $cflag = 1; }
+			    }
 			}
-			
+		
 			#  sometimes there are two directions
 			if($cr > 0 && $pr > 0) { 
 			    # if this is the case we are just going to move on
@@ -1654,20 +1663,24 @@ sub _joinPathsToCenter {
 				if( ($previous eq "CHD") && ($pr > 0)) { $direction++; }
 				if( ($previous eq "PAR") && ($cr > 0)) { $direction++; }
 			    }
+
 			    #  set the previous relation
 			    if($pr > 0){ $previous = "PAR"; }
 			    if($cr > 0){ $previous = "CHD"; }
 			}
 		    }
 
+		    #  if the path starts out with a child relation and then 
+		    #  moves to a parent we don't want it
+		    if($cflag == 1 && $direction >= 1) { next; }
+
 		    #  if there is more than a single direction change 
 		    #  we don't want the path
 		    if($direction > 1) { next; }
-		    
+
 		    #  add the path to the list of shortest paths
 		    my $string = join " ", @path;
 		    push @shortestpaths, $string;
-		    
 		}
 		else {
 
