@@ -131,7 +131,7 @@ this program; if not, write to:
 use UMLS::Interface;
 use Getopt::Long;
 
-eval(GetOptions( "version", "help", "debug", "username=s", "password=s", "hostname=s", "database=s", "socket=s", "infile=s")) or die ("Please check the above mentioned option(s).\n");
+eval(GetOptions( "version", "help", "debug", "username=s", "password=s", "hostname=s", "database=s", "socket=s", "infile=s", "all", "sg")) or die ("Please check the above mentioned option(s).\n");
 
 
 #  if help is defined, print out help
@@ -150,7 +150,7 @@ if( defined $opt_version ) {
 
 # At least 1 term or cui  should be given on the command line.
 # unless the infile option was specified
-if( !(defined $opt_infile) and (scalar(@ARGV) < 1) ) {
+if( !(defined $opt_infile) and !(defined $opt_all) and (scalar(@ARGV) < 1) ) {
     print STDERR "At least 1 term or CUI should be given on the \n";
     print STDERR "command line or use the --infile option\n";
     &minimalUsageNotes();
@@ -189,7 +189,17 @@ $option_hash{"t"} = 1;
 $umls = UMLS::Interface->new(\%option_hash); 
 die "Unable to create UMLS::Interface object.\n" if(!$umls);
 
-
+if(defined $opt_all) { 
+    
+    my $sts = $umls->getAllSts();
+    
+    foreach my $st (@{$sts}) {
+	my $abr = $umls->getStAbr($st);
+	my $string = $umls->getStString($abr);
+	print "  $string ($abr) ($st)\n";
+    }
+    exit; 
+}
 
 my @terms = ();
 if(defined $opt_infile) { 
@@ -204,43 +214,60 @@ else {
     push @terms, $term;
 }
 
-foreach my $input (@terms) {
+if(defined $opt_sg) { 
+    
+    foreach my $input (@terms) { 
+	
+	my $array = $umls->getStsFromSg($input); 
 
-    my $c = undef;
-    if($input=~/C[0-9]/) {
-	push @{$c}, $input;
-	my $ts = $umls->getTermList($input);
-	$term = shift @{$ts};
-    }
-    else {
-	$c = $umls->getConceptList($input);
-    }
-    
-    my $printFlag = 0;
-    
-    foreach my $cui (@{$c}) {
-	
-	my $sts = $umls->getSt($cui);
-	
-	if($#{$sts} < 0) {
-	    print "There are no semantic types associated with $term ($cui)\n";
-	}
-	else {
-	    print "The semantic types associated with $term ($cui):\n";
-	foreach my $st (@{$sts}) {
-	    my $abr = $umls->getStAbr($st);
+	print "The semantic types associated with $input : \n"; 
+	foreach my $abr (@{$array}) {
 	    my $string = $umls->getStString($abr);
 	    print "  $string ($abr)\n";
-	}
-	}
-	$printFlag = 1;
+	}	
+	
     }
+    
+}
+else { 
 
-    if(! ($printFlag) ) {
-	print "There are no semantic types associated with $input\n";
+    foreach my $input (@terms) {
+	
+	my $c = undef;
+	if($input=~/C[0-9]/) {
+	    push @{$c}, $input;
+	    my $ts = $umls->getTermList($input);
+	    $term = shift @{$ts};
+	}
+	else {
+	    $c = $umls->getConceptList($input);
+	}
+	
+	my $printFlag = 0;
+	
+	foreach my $cui (@{$c}) {
+	    
+	    my $sts = $umls->getSt($cui);
+	    
+	    if($#{$sts} < 0) {
+		print "There are no semantic types associated with $term ($cui)\n";
+	    }
+	    else {
+		print "The semantic types associated with $term ($cui):\n";
+		foreach my $st (@{$sts}) {
+		    my $abr = $umls->getStAbr($st);
+		    my $string = $umls->getStString($abr);
+		    print "  $string ($abr)\n";
+		}
+	    }
+	    $printFlag = 1;
+	}
+	
+	if(! ($printFlag) ) {
+	    print "There are no semantic types associated with $input\n";
+	}
     }
 }
-
 ##############################################################################
 #  function to output minimal usage notes
 ##############################################################################
@@ -288,7 +315,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: getSts.pl,v 1.15 2011/08/29 16:37:03 btmcinnes Exp $';
+    print '$Id: getSts.pl,v 1.17 2016/07/11 16:36:48 btmcinnes Exp $';
     print "\nCopyright (c) 2011, Ted Pedersen & Bridget McInnes\n";
 }
 
